package com.muyu.data.processing.service.impl;


import javax.annotation.Resource;

import com.muyu.common.iotdb.config.IotDBConfig;
import com.muyu.data.processing.domain.CarData;
import com.muyu.data.processing.domain.IotDbData;
import com.muyu.data.processing.domain.BasicData;
import com.muyu.data.processing.strategy.core.StartStrategy;
import org.apache.iotdb.isession.SessionDataSet;import org.apache.iotdb.rpc.IoTDBConnectionException;
import org.apache.iotdb.rpc.StatementExecutionException;
import org.apache.iotdb.tsfile.read.common.Field;
import org.apache.iotdb.tsfile.read.common.RowRecord;
import org.springframework.stereotype.Service;
import lombok.extern.slf4j.Slf4j;
import com.muyu.data.processing.mapper.DataProcessingMapper;
import com.muyu.data.processing.service.DataProcessingService;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 数据处理实现层
 *
 * @Author: 胡杨
 * @Name: DataProcessing
 * @Description: 数据处理实现层
 * @CreatedDate: 2024/9/28 下午3:52
 * @FilePath: com.muyu.data.processing.server.impl
 */

@Slf4j
@Service
public class DataProcessingServiceImpl implements DataProcessingService {
    @Resource
    private DataProcessingMapper mapper;
    @Resource
    private IotDBConfig iotDBConfig;


    @Override
    public List<String> selectStorageGroup() {
        return mapper.selectStorageGroup();
    }

    @Override
    public void strategyCheck(List<BasicData> dataList) {
        HashMap<String, BasicData> kafkaDataHashMap = new HashMap<>();
        dataList.forEach(data -> kafkaDataHashMap.put(data.getKey(), data));
//        Result<String[]> result = rootStrategy.applyStrategy(kafkaDataHashMap);
//        String[] data = result.getData();
//        insIotDbData(data[0],data[1]);
        IotDbData build = IotDbData.builder()
                .vin(kafkaDataHashMap.get("vin").getValue())
                .timestamp(Long.parseLong(kafkaDataHashMap.get("timestamp").getValue()))
                .latitude(kafkaDataHashMap.get("latitude").getValue())
                .longitude(kafkaDataHashMap.get("longitude").getValue())
                .build();
        mapper.insIotDbDataVo(build);
//        dataList.forEach(KafkaData::setValueClass);
//        mapper.strategyCheck(dataList);
    }

    @Override
    public Integer insIotDbData(String key, String value) {
        return mapper.insIotDbData(key, value);
    }

    @Override
    public List<CarData> selectCarData(String firmCode, String vin) {
        ArrayList<CarData> carDataList = new ArrayList<>();
        String sql = "select * from root.one."+firmCode+"."+vin;
        try {
            SessionDataSet sessionDataSet = iotDBConfig.iotSession().executeQueryStatement(sql);
            List<String> columnNames = sessionDataSet.getColumnNames();
            while (sessionDataSet.hasNext()){
                RowRecord next = sessionDataSet.next();
                CarData data = getCarData(vin, next, columnNames);
                carDataList.add(data);
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return carDataList;
    }

    private static CarData getCarData(String vin, RowRecord next, List<String> columnNames) {
        List<Field> fields = next.getFields();
        CarData data = new CarData();
        data.setVin(vin);
        data.setTimestamp(next.getTimestamp());
        for (int i = 0; i < columnNames.size(); i++) {
            if (columnNames.get(i).contains("latitude")) {
                data.setLatitude(fields.get(i-1).getStringValue());
            }else if (columnNames.get(i).contains("longitude")) {
                data.setLongitude(fields.get(i-1).getStringValue());
            }
        }
        return data;
    }


}
